# Base configuration for all package types
{% block header_comment %}# Package configuration{% endblock %}

[project]
{% block project %}
# List of packages to initialize
packages = [
    {% block packages %}
    "{{ name }}"
    {% endblock %}
]

{% block plugin_host %}
{% if is_plugin_host %}
# This package will be the plugin host
plugin_host = "{{ name }}"
{% elif is_plugin %}
# Plugin host package
plugin_host = "{{ plugin_host }}"
{% endif %}
{% endblock %}

# Output directory (optional, defaults to current directory)
output_dir = "."
{% endblock %}

{% include '_shared/snippets/author.toml.j2' %}

{% include '_shared/snippets/package.toml.j2' %}

{% block dependencies %}
{% include '_shared/snippets/dependencies.toml.j2' %}

{% if is_plugin_host %}
plugin_dependencies = [
    "pydantic>=2.0.0",
    "importlib-resources>=5.0.0",
    {% for dep in plugin_dependencies | default([]) %}
    "{{ dep }}",
    {% endfor %}
]
{% endif %}
{% endblock %}

{% include '_shared/snippets/development.toml.j2' %}

{% include '_shared/snippets/tools.toml.j2' %}

{% include '_shared/snippets/features.toml.j2' %}

{% block additional_config %}{% endblock %} 